#
# spec file for package clamsap
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%ifarch x86_64
  %define platnum   64
  %define platdir   lib64
  %define platstr   64 bit
  %define platform  linuxx86_64
%else
  %define platnum   32
  %define platdir   lib
  %define platstr   32 bit
  %define platform  linuxintel
%endif

%define packname    clamsap-%{version}
%define requiresp   clamav >= 0.96
%define inslibdir   /usr/%{platdir}

Summary:            Virus Scan Adapter (VSA) for ClamAV
Name:               clamsap
Version:            0.104.3
Release:            150600.17.2
License:            MIT
Group:              Productivity/Security
Source:             https://sourceforge.net/projects/clamsap/files/source/clamsap-%{version}.tar.gz
Source1:            clamsap-on-sles4sap.pdf
URL:                https://sourceforge.net/projects/clamsap/
BuildRoot:          %{_tmppath}/%{name}-%{version}-build
Provides:           %{packname}
Requires:           %{requiresp}
BuildRequires:      %{requiresp}
%if 0%{?suse_version} >= 1030
BuildRequires:      automake
BuildRequires:      libtool
BuildRequires:      check-devel
BuildRequires:      libbz2-devel
BuildRequires:      libopenssl-devel
%endif
%if 0%{?suse_version} >= 1500
BuildRequires:      clamav-devel
%endif
# additional build dependencies for Fedora/RedHat/SLES10
%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version} || 0%{?suse_version} == 1010
BuildRequires:      gcc-c++
%endif


%description
This package provides two %{platstr} shared libraries which link SAP (NW-VSI) and ClamAV
The library clamsap links directly to clamav engine library, the library clamdsap uses the clamd
scan daemon to scan for viruses. Both libraries enable a SAP system to perform antivirus scans.

Authors:
--------
    Markus Strehle

%prep
%setup 
cp %{S:1} ./

%build
autoreconf --force --install
%configure
make

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
rm -rf $RPM_BUILD_ROOT/%_libdir/*.la
rm -rf $RPM_BUILD_ROOT/%_libdir/*.a

%clean  
rm -rf $RPM_BUILD_ROOT

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%doc AUTHORS ChangeLog COPYING COPYING.clamav COPYING.vsa INSTALL NEWS  README clamsap-on-sles4sap.pdf
%defattr(-,root,root,-)
%_libdir/lib* 


%changelog
* Thu Aug 11 2022 varkoly@suse.com
- Fix XML MIME type detection using libmagic
- (bsc#1200699) L3: clamsap threat XML file like a virus
- 0.104.3 (jsc#PED-805)
* Mon Jul 25 2022 varkoly@suse.com
- Update to version 0.104
  (jsc#PED-805) Update clamsap to current version - and update regularly
  * Relax javascript check in PDF
  * use https source url, also https URL
  * Wildcard support for MIME type lists
  * Fix SAR file content scan
  * Add option for PDF active content
  * Remove own default settings from VsaGetConfig and rely on clamav defaults
  * Change default virusname in case clamav does not return any virus name.
  * Limit pcre calls
  * Increase Version because tested with latest clam engine
  * Support new parameter SCANHEURISTICLEVEL
* Thu Mar  4 2021 varkoly@suse.com
- Update dokumentation
  (bsc#1181586) SLES15 SP2: ClamAV/ClamSAP allocates 1GB of anon
  memory segment for each SAP worker process
- JIRA-TEAM-3439 Backport clamsap from openSUSE:security to SLES
- Update to version 0.101.9
  * enhance jpeg detection
  * fix mime type check for html
  * use short MIME types always
  * use IANA type for SAR, see https://www.iana.org/assignments/media-types/media-types.xhtml
  * copyright update
  * correct application/octet-stream
  * prevent overflow
  * Use libmagic for buffer scan
  * Fix interface change from clamav 0.101.0
  * Fix parser of SAR files
  * Fix MIME detection for TEXT files
  * fix MIME type detection for multi byte
  * improve load of libclamav on linux
- Adapt automake version:
  adapt-automake-version.pach
* Thu Jan 11 2018 varkoly@suse.com
- bsc#1074649 clamsap build fail
  Add missed package (clamav-devel) to spec.
* Wed May  3 2017 varkoly@suse.com
- FATE#322612 Document setup and usage of clamsap
* Sat Mar 25 2017 varkoly@suse.com
- Update to Version 0.99.25
  * Add Office Mime Detected, to be independent from libmagic
  * Fix compare of block extension, soves https://sourceforge.net/p/clamsap/bugs/2/
  * Check for SAR extract
* Mon Dec 28 2015 varkoly@suse.com
- Update to Version 0.98.9
- Improve MIME check
- Fix SAP archive decompression
- Enhance error messages in case of initialisation errors.
- Create default sym.link for libclamdsap
- Fix problem, if libmagic can not be found in VsaStartup
- Security fix for compression, see CVE-2015-2282 and CVE-2015-2278
- Enhance buffer scan in libclamdsap
- Support of NW-VSI 2.00
  This includes the support of MIME type detection in addition to AV.
  Use code from SAP example adapter to provide SAP archive format scan.
  see http://scn.sap.com/docs/DOC-7838
* Wed Feb 11 2015 varkoly@suse.com
- Update to Version 0.9.7.4
- Remove patch clamsap-mktime.patch
* Mon Mar  5 2012 max@suse.com
- Copy package from the security project in OBS.
- Cleanup spec file
- Add clamsap-mktime.patch to remove a known broken autoconf test.
